@@ -1,6 +1,8 @@
 from dataclasses import dataclass
+
 from algosdk.atomic_transaction_composer import AccountTransactionSigner
 from algosdk.kmd import KMDClient
+from algosdk.wallet import Wallet
 
 DEFAULT_KMD_ADDRESS = "http://localhost:4002"
 DEFAULT_KMD_TOKEN = "a" * 64
@@ -8,6 +10,20 @@ DEFAULT_KMD_WALLET_NAME = "unencrypted-default-wallet"
 DEFAULT_KMD_WALLET_PASSWORD = ""
 
 
+def get_client() -> KMDClient:
+    """creates a new kmd client using the default sandbox parameters"""
+    return KMDClient(kmd_token=DEFAULT_KMD_TOKEN, kmd_address=DEFAULT_KMD_ADDRESS)
+
+
+def get_sandbox_default_wallet() -> Wallet:
+    """returns the default sandbox kmd wallet"""
+    return Wallet(
+        wallet_name=DEFAULT_KMD_WALLET_NAME,
+        wallet_pswd=DEFAULT_KMD_WALLET_PASSWORD,
+        kmd_client=get_client(),
+    )
+
+
 @dataclass
 class SandboxAccount:
     """SandboxAccount is a simple dataclass to hold a sandbox account details"""
